@@ -243,6 +243,30 @@ def create_proc_pass_map(job_names, version, default_proc_pass="default"):
     return proc_pass_map
 
 
+def is_simulation_job(prod_data: dict, job_name: str):
+    """Determine if a job is using MC input or not.
+
+    :param prod_data: Entire production information from yaml parsing
+    :param job_name: Name of the job to determine if it's using MC input or not
+    :returns: True if the job is using MC input, False if it is not
+    """
+
+    job_dict = prod_data[job_name]
+    if "simulation" not in job_dict:
+        if "bk_query" in job_dict["input"]:
+            if "/mc/" in job_dict["input"]["bk_query"].lower():
+                return True
+            else:
+                return False
+        elif "job_name" in job_dict["input"]:
+            dependent_job = prod_data[job_name]["input"]["job_name"]
+            return is_simulation_job(prod_data, dependent_job)
+        else:
+            raise NotImplementedError(
+                "Input requires either a bookkeeping location or a previous job name"
+            )
+
+
 def parse_yaml(rendered_yaml):
     data1 = load(
         rendered_yaml, schema=MapPattern(Regex(RE_JOB_NAME), Any(), minimum_keys=1)
