@@ -607,6 +607,12 @@ def test_good_with_checks_no_defaults():
         check_num_entries_per_invpb:
             type: num_entries_per_invpb
             count_per_invpb: 12.5
+        check_branches_exist:
+            type: branches_exist
+            branches:
+                - Dst_M
+                - D0_M
+                - D0_Eta
 
     job_1:
         application: DaVinci/v45r3
@@ -623,6 +629,7 @@ def test_good_with_checks_no_defaults():
             - check_range_nd
             - check_num_entries
             - check_num_entries_per_invpb
+            - check_branches_exist
     """
     )
     jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
@@ -642,6 +649,7 @@ def test_good_with_checks_no_defaults():
         "check_range_nd",
         "check_num_entries",
         "check_num_entries_per_invpb",
+        "check_branches_exist",
     ]
 
     assert checks_data["check_range"]["type"] == "range"
@@ -679,6 +687,13 @@ def test_good_with_checks_no_defaults():
     assert checks_data["check_num_entries_per_invpb"]["type"] == "num_entries_per_invpb"
     assert checks_data["check_num_entries_per_invpb"]["count_per_invpb"] == 12.5
 
+    assert checks_data["check_branches_exist"]["type"] == "branches_exist"
+    assert checks_data["check_branches_exist"]["branches"] == [
+        "Dst_M",
+        "D0_M",
+        "D0_Eta",
+    ]
+
 
 def test_good_with_checks_defaults_extra_checks():
     rendered_yaml = dedent(
